SWDEV-339113 - update coordinate in HIP sample kernels (#2736)
Change-Id: I8ea179b4ba8f1c0ebec830a5aa5947e843f06e42
This commit is contained in:
committed by
GitHub
parent
14a136c3e2
commit
a94de8f202
@@ -36,7 +36,7 @@ THE SOFTWARE.
|
||||
|
||||
// Device (Kernel) function, it must be void
|
||||
__global__ void matrixTranspose(float* out, float* in, const int width) {
|
||||
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
|
||||
int x = blockDim.x * blockIdx.x + threadIdx.x;
|
||||
|
||||
float val = in[x];
|
||||
|
||||
|
||||
Reference in New Issue
Block a user